#ifndef _LWIPOPTS_H
#define _LWIPOPTS_H

// dummy lwip opts to allow compilation

#define NO_SYS                      1
#define LWIP_DHCP                   1
#define LWIP_RAW                    1
#define LWIP_NETIF_HOSTNAME         1
#define LWIP_NETIF_STATUS_CALLBACK  1
#define LWIP_DNS                    1
#define LWIP_SOCKET                 0
#define LWIP_NETCONN                0

// For testing mbedtls
#define LWIP_ALTCP               	1
#define LWIP_ALTCP_TLS           	1
#define LWIP_ALTCP_TLS_MBEDTLS   	1

#endif
